# Projeto 02 - DIO / Unimed

Descrição
Esse é um projeto de teste para utilização de pacotes para o BootCamp DIO/Unimed para Ciência de Dados.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install package_name
```

## Usage

```python
from package_name.module1_name import file1_name
file1_name.my_function()
```

## Author
Igor Mata

## License
[MIT](https://choosealicense.com/licenses/mit/)